=== modified file 'bzrlib/tests/test_lazy_regex.py'
--- bzrlib/tests/test_lazy_regex.py	2011-05-13 12:51:05 +0000
+++ bzrlib/tests/test_lazy_regex.py	2011-06-13 22:11:11 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,7 +41,8 @@
     def _real_re_compile(self, *args, **kwargs):
         self._actions.append(('_real_re_compile',
                                                args, kwargs))
-        return super(InstrumentedLazyRegex, self)._real_re_compile(*args, **kwargs)
+        return super(InstrumentedLazyRegex, self)._real_re_compile(
+            *args, **kwargs)
 
 
 class TestLazyRegex(tests.TestCase):
@@ -116,12 +117,18 @@
 
 
 class TestInstallLazyCompile(tests.TestCase):
+    """Tests for lazy compiled regexps.
+
+    Other tests, and bzrlib in general, count on the lazy regexp compiler
+    being installed, and this is done by loading bzrlib.  So these tests
+    assume it is installed, and leave it installed when they're done.
+    """
 
     def setUp(self):
         super(TestInstallLazyCompile, self).setUp()
-        self.addCleanup(lazy_regex.reset_compile)
 
     def test_install(self):
+        lazy_regex.reset_compile()
         lazy_regex.install_lazy_compile()
         pattern = re.compile('foo')
         self.assertIsInstance(pattern, lazy_regex.LazyRegex)
@@ -129,10 +136,11 @@
     def test_reset(self):
         lazy_regex.install_lazy_compile()
         lazy_regex.reset_compile()
+        self.addCleanup(lazy_regex.install_lazy_compile)
         pattern = re.compile('foo')
         self.assertFalse(isinstance(pattern, lazy_regex.LazyRegex),
-                    'lazy_regex.reset_compile() did not restore the original'
-                    ' compile() function %s' % (type(pattern),))
+            'lazy_regex.reset_compile() did not restore the original'
+            ' compile() function %s' % (type(pattern),))
         # but the returned object should still support regex operations
         m = pattern.match('foo')
         self.assertEqual('foo', m.group())

